/*This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.*/

#include "leds.h"

/* Gestione dei "fusibili" di configurazione */
typedef unsigned int word;
word at 0x2007 CONFIG = _WDT_OFF & _PWRTE_OFF & _INTOSC_OSC_NOCLKOUT &
                        _MCLRE_OFF & _BOREN_OFF & _LVP_OFF & _DATA_CP_OFF & _CP_OFF;

/* Dichiarazione delle variabili globali */
// unsigned char ledsVal = 0xFF;
static unsigned char b_TMR_FLAGS = 0x00;

static unsigned char Timer1Count = 0x00;
static unsigned char Timer2Count = 0x00;

/* --- Vettore di interrupt --- */
static void interruptfunc(void) /* shadowregs */ interrupt 0
{
  if(TMR1IF)
  {
    TMR1IF     = 0x0;

    TMR1H      = 0xFC;  // Timer principale  CLK_INT= 1MHz
    TMR1L      = 0x17;

    TMR1IE     = 0x1;

    b_TMR_FLAGS |= 0x01;
  }
}
/* --- Implementazione funzioni --- */

/* Inizializza l'hardware */
static void InitMicro(void)
{
  /* Inizializza le porte IO usate */
  GIE        = 0x0;     //CLI                            ;Disabilita master IRQ
  PORTA      = 0x00;  // CLRF PORTA                      ;Inizializza PORTA
  CMCON      = 0x07;  // MOVLF 0x07,CMCON                ;disabilita comparatori
  PCON       = 0x0B;  // MOVLF 0xB,PCON                  ;Setta osc. interno 4MHz
  TRISA      = 0x3D;  // MOVLF 0xFD,TRISA                ;Setta RA7,RA6,RA1 come uscite
  TRISB      = 0xC0;  // MOVLF 0xC0,TRISB                ;Setta RB5,RB4,RB3,RB2,RB1,RB0 come uscite
  PORTA      = 0xFF;  //MOVLF 0xC2,PORTA                ;
  PORTB      = 0xFF;  //MOVLF 0xC2,PORTA                ;

  /** BEGIN: Timer initializer */
  TMR1ON     = 0x0;
  TMR1H      = 0xFC;  // Timer principale  CLK_INT= 1MHz
  TMR1L      = 0x17;
  PIR1       = 0x00;
  TMR1IE     = 0x1;
  T1CON      = 0x00;
  TMR1ON     = 0x01;
  /** END: Timer initializer */

  Timer1Count = 0xFF;
  Timer2Count = 0xFF;

  PEIE       = 0x01;
  GIE        = 0x1;
}



/* Questo e' il programma principale! --------------- */
void main (void)
{
  unsigned char count1 = 0;
  unsigned char count2 = 0;

  /* Inizializza l'hardware */
  InitMicro();

  /* Accendo il led verde: si parte! */
  PORTA = 0x3D; //0011 1101  LED ROSSO ON + RA7,RA6 ON
  PORTB = 0xC0; //1100 0000  RB5,RB4,RB3,RB2,RB1,RB0 ON

  for(count1=255;count1>0;count1--)
    for(count2=255;count2>0;count2--)
            ;

  PORTA  = 0xFD; //1111 1101  LED ROSSO ON
  PORTB  = 0xFF; //1111 1111  RB5,RB4,RB3,RB2,RB1,RB0 OFF
  count1 = 0;

  /* Esegui per sempre ... */
  while (1)
  {
    if(b_TMR_FLAGS & 0x01)
    {
      b_TMR_FLAGS &=0xFE;  //clear stato IRQ
      Timer1Count -=1;
      if(Timer1Count==0)
      {
        Timer1Count = 0xFF;
        if(PORTA & 0x02)
        {
          //PORTA &= 0xFD;
          PORTA &= 0x3D; //0011 11x1  LED ROSSO ON + RA7,RA6 ON
          PORTB &= 0xC0; //1100 0000  RB5,RB4,RB3,RB2,RB1,RB0 ON
        }
        else
        {
          //PORTA |= 0x02; //0xFF;
          PORTA |= 0xC2; //1100 00x0  LED ROSSO ON
          PORTB |= 0x3F; //0011 1111  RB5,RB4,RB3,RB2,RB1,RB0 OFF
        }
      }
    }
  }
}

