#ifndef _LEDS_H_
#define _LEDS_H_

#include <pic16f628a.h>

/* Alcune utili definizioni */
#ifndef OFF
#define OFF  1
#endif

#ifndef ON
#define ON   0
#endif

#define ARMA_WATCHDOG _asm clrwdt _endasm

#define MAXNUMEROLED   8


// ;_______________________________________________________Costanti
// ;primo led acceso
#define FIRST_LED       0x7F
// ;ultimo led acceso
#define LAST_LED        0xFE
// ;primo ed ultimo led acceso
#define EXT_LED         0x7E
// ;maschera per clear stato programmi
#define ST_MASK         0x07
// PORTA,1         ;led indicatore "run"
#define RUN_LED         (PORTA & 0x02)

/** Bit Test */
// b_CONTROLLO,0   ;controllo direzione
#define CTR_DIR         (b_CONTROLLO & 0x01)
// b_CONTROLLO,1   ;flag di esecuzione programmi
#define CTR_RUN         (b_CONTROLLO & 0x02)
// b_CONTROLLO,2   ;flag esecuzione PWM PROG5
#define CTR_5PW         (b_CONTROLLO & 0x04)
// b_CONTROLLO,3   ;flag esecuzione PROG5
#define CTR_P5          (b_CONTROLLO & 0x08)
// b_CONTROLLO,4   ;flag esecuzione PROG4
#define CTR_P4          (b_CONTROLLO & 0x10)
// b_CONTROLLO,5   ;flag esecuzione PROG3
#define CTR_P3          (b_CONTROLLO & 0x20)
// b_CONTROLLO,6   ;flag esecuzione PROG2
#define CTR_P2          (b_CONTROLLO & 0x40)
// b_CONTROLLO,7   ;flag esecuzione PROG1
#define CTR_P1          (b_CONTROLLO & 0x80)

// b_STATO,0       ;flag cambio stato
#define ST_CHG          (b_STATO & 0x01)

// b_STATO,3       ;flag stato PROG5
#define ST_P5           (b_STATO & 0x08)
// b_STATO,4       ;flag stato PROG4
#define ST_P4           (b_STATO & 0x10)
// b_STATO,5       ;flag stato PROG3
#define ST_P3           (b_STATO & 0x20)
// b_STATO,6       ;flag stato PROG2
#define ST_P2           (b_STATO & 0x40)
// b_STATO,7       ;flag stato PROG1
#define ST_P1           (b_STATO & 0x80)

// b_SW_CTRL,0     ;flag di stato pulsante selezione
#define SW_SEL_STAT     (b_SW_CTRL & 0x01)
// b_SW_CTRL,1     ;flag di cambio stato pulsante selezione
#define SW_SEL_CHG      (b_SW_CTRL & 0x02)
// b_SW_CTRL,2     ;flag di stato pulsante start/stop
#define SW_ST_STAT      (b_SW_CTRL & 0x04)
// b_SW_CTRL,3     ;flag di cambio stato pulsante start/stop
#define SW_ST_CHG       (b_SW_CTRL & 0x10)


/** Bit Clear */
// PORTA,1         ;led indicatore "run"
#define RUN_LED_CLEAR    (PORTA & 0xFD)

// ;controllo direzione
#define CTR_DIR_CLEAR    (b_CONTROLLO & 0xFE)
// ;flag di esecuzione programmi
#define CTR_RUN_CLEAR    (b_CONTROLLO & 0xFD)
// ;flag esecuzione PWM PROG5
#define CTR_5PW_CLEAR    (b_CONTROLLO & 0xFB)
// ;flag esecuzione PROG5
#define CTR_P5_CLEAR     (b_CONTROLLO & 0xF7)
// ;flag esecuzione PROG4
#define CTR_P4_CLEAR     (b_CONTROLLO & 0xEF)
// ;flag esecuzione PROG3
#define CTR_P3_CLEAR     (b_CONTROLLO & 0xDF)
// ;flag esecuzione PROG2
#define CTR_P2_CLEAR     (b_CONTROLLO & 0xBF)
// ;flag esecuzione PROG1
#define CTR_P1_CLEAR     (b_CONTROLLO & 0x7F)

//;flag di cambio stato pulsante start/stop
#define SW_ST_CHG_CLEAR  (b_SW_CTRL & 0xEF)

/** Bit Set */
// PORTA,1         ;led indicatore "run"
#define RUN_LED_SET      (PORTA | 0x02)
#define LED_SET(bitMask) { PORTA = ((bitMask & 0xC0)|(PORTA & 0x02));\
                           PORTB = ((bitMask & 0x3F)|(PORTB & 0xC0));}

// ;controllo direzione
#define CTR_DIR_SET      (b_CONTROLLO | 0x01)
// ;flag di esecuzione programmi
#define CTR_RUN_SET      (b_CONTROLLO | 0x02)
// ;flag esecuzione PWM PROG5
#define CTR_5PW_SET      (b_CONTROLLO | 0x04)
// ;flag esecuzione PROG5
#define CTR_P5_SET       (b_CONTROLLO | 0x08)
// ;flag esecuzione PROG4
#define CTR_P4_SET       (b_CONTROLLO | 0x10)
// ;flag esecuzione PROG3
#define CTR_P3_SET       (b_CONTROLLO | 0x20)
// ;flag esecuzione PROG2
#define CTR_P2_SET       (b_CONTROLLO | 0x40)
// ;flag esecuzione PROG1
#define CTR_P1_SET       (b_CONTROLLO | 0x80)

//;flag di cambio stato pulsante start/stop
#define SW_ST_CHG_SET    (b_SW_CTRL | 0x10)

#define PWR_LED_ON       {PORTA &= 0xFD;}
#define PWR_LED_OFF      {PORTA |= 0x02;}

#define LED0_ON       {PORTB &= 0xFE;}
#define LED0_OFF      {PORTB |= 0x01;}
#define LED1_ON       {PORTB &= 0xFD;}
#define LED1_OFF      {PORTB |= 0x02;}
#define LED2_ON       {PORTB &= 0xFB;}
#define LED2_OFF      {PORTB |= 0x04;}
#define LED3_ON       {PORTB &= 0xF7;}
#define LED3_OFF      {PORTB |= 0x08;}
#define LED4_ON       {PORTB &= 0xEF;}
#define LED4_OFF      {PORTB |= 0x10;}
#define LED5_ON       {PORTA &= 0xDF;}
#define LED5_OFF      {PORTA |= 0x20;}

#define LED6_ON       {PORTA &= 0xBF;}
#define LED6_OFF      {PORTA |= 0x40;}
#define LED7_ON       {PORTA &= 0x7F;}
#define LED7_OFF      {PORTA |= 0x80;}

#define LED0_ST       (PORTB & 0x01)
#define LED1_ST       (PORTB & 0x02)
#define LED2_ST       (PORTB & 0x04)
#define LED3_ST       (PORTB & 0x08)
#define LED4_ST       (PORTB & 0x10)
#define LED5_ST       (PORTA & 0x20)

#define LED6_ST       (PORTA & 0x40)
#define LED7_ST       (PORTA & 0x80)

#define SW1_ST        (PORTA & 0x01)
#define SW2_ST        (PORTA & 0x04)


// ;_______________________________________________________Pulsanti
// ;pulsante di selezione
#define SW_SELECT       (PORTA | 0x01)
// ;pulsante di start/stop
#define SW_STST         (PORTA | 0x02)

/**
 * ;bit da controllare per buffer tasti
   ; con il clock a 1ms, occorrono 64ms
   ; per un cambio stato del pulsante
*/
#define SW_BIT          6


#endif /* _LEDS_H_ */



